@@ -111,19 +111,17 @@ def load_plugin_from_path(file_path, scope=None):
         scope = scope or PLUGIN_SCOPE_SERVICES
         if scope == PLUGIN_SCOPE_COMMANDS:
             method_name = 'register_localstack_commands'
-        LOG.debug('Loading plugins - scope "%s", module "%s"' % (scope, module))
         try:
             namespace = {}
             exec('from %s.plugins import %s' % (module, method_name), namespace)
             method_to_execute = namespace[method_name]
         except Exception as e:
-            if "cannot import name 'register_localstack_commands'" not in str(e):
-                print('Unable to load plugins for module "%s": %s' % (module, e))
             if (not re.match(r'.*cannot import name .*%s.*' % method_name, str(e)) and
                     ('No module named' not in str(e))):
                 LOG.debug('Unable to load plugins from module %s: %s' % (module, e))
             return
         try:
+            LOG.debug('Loading plugins - scope "%s", module "%s": %s' % (scope, module, method_to_execute))
             return method_to_execute()
         except Exception as e:
             if not os.environ.get(ENV_SCRIPT_STARTING_DOCKER):
@@ -334,6 +332,15 @@ class PortMappings(object):
             raise Exception('Unable to add port %s to existing range %s' % (port, range))
 
 
+def get_docker_image_to_start():
+    image_name = os.environ.get('IMAGE_NAME')
+    if not image_name:
+        image_name = constants.DOCKER_IMAGE_NAME
+        if os.environ.get('USE_LIGHT_IMAGE') in constants.TRUE_STRINGS:
+            image_name = constants.DOCKER_IMAGE_NAME_LIGHT
+    return image_name
+
+
 def start_infra_in_docker():
 
     container_name = MAIN_CONTAINER_NAME
@@ -353,7 +360,7 @@ def start_infra_in_docker():
     entrypoint = os.environ.get('ENTRYPOINT', '')
     cmd = os.environ.get('CMD', '')
     user_flags = config.DOCKER_FLAGS
-    image_name = os.environ.get('IMAGE_NAME', constants.DOCKER_IMAGE_NAME)
+    image_name = get_docker_image_to_start()
     service_ports = config.SERVICE_PORTS
     force_noninteractive = os.environ.get('FORCE_NONINTERACTIVE', '')
 
